.. image:: https://i.imgur.com/HPOdOsR.png

An xarray wrapper for analysis of ensemble forecast models for climate prediction.

.. image:: https://travis-ci.org/bradyrx/climpred.svg?branch=master
    :target: https://travis-ci.org/bradyrx/climpred

.. image:: https://img.shields.io/pypi/v/climpred.svg
   :target: https://pypi.python.org/pypi/climpred/

.. image:: https://img.shields.io/conda/vn/conda-forge/climpred.svg
    :target: https://anaconda.org/conda-forge/climpred
    :alt: Conda Version

.. image:: https://coveralls.io/repos/github/bradyrx/climpred/badge.svg?branch=master
    :target: https://coveralls.io/github/bradyrx/climpred?branch=master

.. image:: https://img.shields.io/readthedocs/climpred/stable.svg?style=flat
    :target: https://climpred.readthedocs.io/en/stable/?badge=stable
    :alt: Documentation Status

.. image:: https://badges.gitter.im/Join%20Chat.svg
    :target: https://gitter.im/climpred

.. image:: https://img.shields.io/github/license/bradyrx/climpred.svg
    :alt: license
    :target: LICENSE.txt

Installation
============

You can install the latest release of ``climpred`` using ``pip`` or ``conda``:

.. code-block:: bash

    pip install climpred

.. code-block:: bash

    conda install -c conda-forge climpred

You can also install the bleeding edge (pre-release versions) by cloning this
repository and running ``pip install . --upgrade`` in the main directory.

Documentation
=============

Documentation is in development and can be found on readthedocs_.

.. _readthedocs: https://climpred.readthedocs.io/en/latest/
